api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear package — Argus-Toolbelt 1.0 documentation

# api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear package

## Submodules

## api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.clear_cached_configurations module

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.clear_cached_configurations.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/cachedconfigurations/clear, respond with HTTP 403

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.clear_cached_configurations.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/cachedconfigurations/clear, respond with HTTP 404

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.clear_cached_configurations.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/cachedconfigurations/clear, respond with HTTP 200

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.clear_cached_configurations.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/cachedconfigurations/clear, respond with HTTP 401

## api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.compact_persistence module

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.compact_persistence.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/persistence/compact, respond with HTTP 403

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.compact_persistence.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/persistence/compact, respond with HTTP 404

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.compact_persistence.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/persistence/compact, respond with HTTP 200

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.compact_persistence.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/persistence/compact, respond with HTTP 401

## api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.install_all module

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.install_all.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/installAll, respond with HTTP 403

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.install_all.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/installAll, respond with HTTP 404

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.install_all.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/installAll, respond with HTTP 200

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.install_all.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/installAll, respond with HTTP 401

## api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.list_persistent_components module

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.list_persistent_components.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/persistence, respond with HTTP 403

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.list_persistent_components.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/persistence, respond with HTTP 404

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.list_persistent_components.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/persistence, respond with HTTP 200

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.list_persistent_components.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/persistence, respond with HTTP 401

## api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.reboot module

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.reboot.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/reboot, respond with HTTP 403

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.reboot.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/reboot, respond with HTTP 404

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.reboot.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/reboot, respond with HTTP 200

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.reboot.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/reboot, respond with HTTP 401

## api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.refresh_host_status module

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.refresh_host_status.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/status/refresh, respond with HTTP 403

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.refresh_host_status.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/status/refresh, respond with HTTP 404

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.refresh_host_status.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/status/refresh, respond with HTTP 200

`api.system.components.runtime.v1.host.cachedconfigurations.test_helpers.host_cachedconfigurations_clear.refresh_host_status.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/runtime/v1/host/w+/status/refresh, respond with HTTP 401

## Module contents